OC.L10N.register(
    "core",
    {
    "Please select a file." : "Palun vali fail.",
    "File is too big" : "Fail on liiga suur",
    "Invalid file provided" : "Vigane fail",
    "No image or file provided" : "Ühtegi pilti või faili pole pakutud",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Invalid image" : "Vigane pilt",
    "An error occurred. Please contact your admin." : "Tekkis tõrge. Palun võta ühendust administraatoriga.",
    "No temporary profile picture available, try again" : "Ühtegi ajutist profiili pilti pole saadaval, proovi uuesti",
    "No crop data provided" : "Lõikeandmeid ei leitud",
    "No valid crop data provided" : "Korrektseid lõikeandmeid ei leitud",
    "Crop is not square" : "Lõikamine pole ruudukujuline",
    "%s password changed successfully" : "%s parool on muudetud",
    "%s password reset" : "%s parooli lähtestus",
    "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
    "Download / View" : "Laadi alla / Vaata",
    "Download / View / Upload" : "Laadi alla / Vaata / Laadi üles",
    "Download / View / Edit" : "Laadi alla / Vaata / Muuda",
    "Upload only" : "Ainult üleslaadimine",
    "Preparing update" : "Uuendamise ettevalmistamine",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Paranda hoiatus:",
    "Repair error: " : "Paranda viga:",
    "[%d / %d]: Checking table %s" : "[%d / %d]: tabeli kontrollimine %s",
    "Turned on maintenance mode" : "Haldusrežiimis sisse lülitatud",
    "Turned off maintenance mode" : "Haldusrežiimis välja lülitatud",
    "Maintenance mode is kept active" : "Hooldusrežiim on aktiivne",
    "Updating database schema" : "Andmebaasi skeemi uuendamine",
    "Updated database" : "Uuendatud andmebaas",
    "Checked database schema update" : "Andmebaasi skeemi uuendus kontrollitud",
    "Checking updates of apps" : "Rakenduse uuenduste kontrollimine",
    "Checked database schema update for apps" : "Andmebaasi skeemi uuendus rakendustele on kontrollitud",
    "Updated \"%s\" to %s" : "Uuendatud \"%s\" -> %s",
    "Set log level to debug" : "Määra veatuvastuse logimise tase",
    "Reset log level" : "Nulli logimise tase",
    "Starting code integrity check" : "Koodi seisundi kontrollimise alustamine",
    "Finished code integrity check" : "Koodi seisundi kontrollimine on lõpetatud",
    "%s (3rdparty)" : "%s (3nda osapoole arendaja)",
    "%s (incompatible)" : "%s (pole ühilduv)",
    "Following apps have been disabled: %s" : "Järgnevad rakendused on välja lülitatud: %s",
    "Already up to date" : "On juba ajakohane",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Sun." : "P",
    "Mon." : "E",
    "Tue." : "T",
    "Wed." : "K",
    "Thu." : "N",
    "Fri." : "R",
    "Sat." : "L",
    "Su" : "P",
    "Mo" : "E",
    "Tu" : "T",
    "We" : "K",
    "Th" : "N",
    "Fr" : "R",
    "Sa" : "L",
    "January" : "Jaanuar",
    "February" : "Veebruar",
    "March" : "Märts",
    "April" : "Aprill",
    "May" : "Mai",
    "June" : "Juuni",
    "July" : "Juuli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktoober",
    "November" : "November",
    "December" : "Detsember",
    "Jan." : "Jaan.",
    "Feb." : "Veebr.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sept.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dets.",
    "Settings" : "Seaded",
    "Problem loading page, reloading in 5 seconds" : "Lehe laadimisel tekkis tõrge, 5 sekundi pärast laaditakse leht uuesti.",
    "Saving..." : "Salvestamine...",
    "Dismiss" : "Jäta vahele",
    "seconds ago" : "sekundit tagasi",
    "Enter license key" : "Sisesta litsentsivõti",
    "Set new key" : "Määra uus litsentsivõti",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sinu failid on krüpteeritud. Kui sa pole taastamise võtit veel määranud, siis pole präast parooli taastamist mingit võimalust sinu andmeid tagasi saada. <br />Kui sa pole kindel, mida teha, siis palun väta enne jätkamist ühendust oma administaatoriga. <br />Oled sa kindel, et sa soovid jätkata?",
    "I know what I'm doing" : "Ma tean mida teen",
    "Password can not be changed. Please contact your administrator." : "Parooli ei saa muuta. Palun kontakteeru oma süsteemihalduriga.",
    "No" : "Ei",
    "Yes" : "Jah",
    "Choose" : "Vali",
    "Error loading file picker template: {error}" : "Viga failivalija malli laadimisel:  {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Viga sõnumi malli laadimisel: {error}",
    "read-only" : "kirjutuskaitstud",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failikonflikt","{count} failikonflikti"],
    "One file conflict" : "Üks failikonflikt",
    "New Files" : "Uued failid",
    "Already existing files" : "Juba olemasolevad failid",
    "Which files do you want to keep?" : "Milliseid faile sa soovid alles hoida?",
    "If you select both versions, the copied file will have a number added to its name." : "Kui valid mõlemad versioonid, siis lisatakse kopeeritud faili nimele number.",
    "Cancel" : "Loobu",
    "Continue" : "Jätka",
    "(all selected)" : "(kõik valitud)",
    "({count} selected)" : "({count} valitud)",
    "Error loading file exists template" : "Viga faili olemasolu malli laadimisel",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Serveril puudub toimiv internetiühendus. See tähendab, et mõned funktsionaalsused, nagu näiteks väliste andmehoidlate ühendamine, teavitused uuendustest või kolmandate osapoolte rakenduste paigaldamine ei tööta. Eemalt failidele ligipääs ning teadete saatmine emailiga ei pruugi samuti toimida. Kui soovid täielikku funktsionaalsust, siis soovitame serverile tagada ligipääs internetti.",
    "Error occurred while checking server setup" : "Serveri seadete kontrolimisel tekkis viga",
    "Shared" : "Jagatud",
    "Shared with {recipients}" : "Jagatud {recipients}",
    "Error" : "Viga",
    "Error while sharing" : "Viga jagamisel",
    "Error while unsharing" : "Viga jagamise lõpetamisel",
    "The public link will expire no later than {days} days after it is created" : "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
    "Expiration" : "Aegumine",
    "Choose an expiration date" : "Vali aegumise kuupäev",
    "Expiration date is required" : "Aegumise kuupäev on nõutud",
    "Delete {link}" : "Kustuta {link}",
    "Remove link" : "Eemalda link",
    "Link" : "Link",
    "Create public link" : "Loo avalik link",
    "Edit" : "Muuda",
    "Remove" : "Eemalda",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Social share" : "Sotsiaalvõrgustikus jagamine",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘-C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl-C.",
    "Choose a password" : "Vali parool",
    "Password required" : "Parool on nõutud",
    "Link name" : "Lingi nimi",
    "Name" : "Nimi",
    "Filename" : "Failinimi",
    "Password" : "Parool",
    "Edit link share: {name}" : "Muuda jagamise link: {name}",
    "Create link share: {name}" : "Loo lingiga jagamine: {name}",
    "Share" : "Jaga",
    "Save" : "Salvesta",
    "Remove password" : "Eemalda parool",
    "Share to Twitter. Opens in a new window." : "Jaga Twitteris. Avaneb uues aknas.",
    "Share to Facebook. Opens in a new window." : "Jaga Facebookis. Avaneb uues aknas.",
    "Share to Diaspora. Opens in a new window." : "Jaga Diasporas. Avaneb uues aknas.",
    "Share to Google+. Opens in a new window." : "Jaga Google plusis. Avaneb uues aknas.",
    "Share via email. Opens your mail client." : "Jaga e-postiga. Avab sinu meilikliendi",
    "Email link to person" : "Saada link isikule e-postiga",
    "Send copy to self" : "Saada koopia ka endale",
    "Send link via email" : "Jaga linki e-postiga",
    "Add personal message" : "Lisa isiklik sõnum",
    "Sending" : "Saatmine",
    "Shared with you and the group {group} by {owner}" : "Jagatud sinu ja {group} grupiga {owner} poolt",
    "Shared with you by {owner}" : "Sinuga jagas {owner}",
    "group" : "grupp",
    "notify by email" : "teavita e-postiga",
    "Unshare" : "Lõpeta jagamine",
    "can share" : "saab jagada",
    "can edit" : "saab muuta",
    "create" : "loo",
    "change" : "muuda",
    "delete" : "kustuta",
    "access control" : "ligipääsukontroll",
    "Could not unshare" : "Jagamise lõpetamine ebaõnnestus",
    "No users found for {search}" : "Otsinguga {search} ei leitud ühtegi kasutajat",
    "An error occurred. Please try again" : "Tekkis tõrge. Palu proovi uuesti",
    "User" : "Kasutaja",
    "Group" : "Grupp",
    "Guest" : "Külaline",
    "User and Groups" : "Kasutajad ja grupid",
    "Public Links" : "Avalikud lingid",
    "Sharing is not allowed" : "Jagamine pole lubatud",
    "Share with users…" : "Jaga kasutajatega...",
    "Share with users, groups or remote users…" : "Jaga kasutajate, gruppide või kaugkasutajatega...",
    "Share with users or groups…" : "Jaga kasutajate või gruppidega...",
    "Share with users or remote users…" : "Jaga kasutajate või kaugkasutajatega...",
    "Error removing share" : "Jagamise eemaldamisel tekkis tõrge",
    "Unknown Share" : "Tundmatu jagamine",
    "Non-existing tag #{tag}" : "Silti #{tag} pole olemas",
    "restricted" : "piiratud",
    "invisible" : "nähtamatu",
    "Static" : "Staatiline",
    "({scope})" : "({scope})",
    "Delete" : "Kustuta",
    "Rename" : "Nimeta ümber",
    "Collaborative tags" : "Koostöö sildid",
    "The object type is not specified." : "Objekti tüüp pole määratletud.",
    "Enter new" : "Sisesta uus",
    "Add" : "Lisa",
    "Edit tags" : "Muuda silte",
    "Error loading dialog template: {error}" : "Viga dialoogi malli laadimisel: {error}",
    "No tags selected for deletion." : "Kustutamiseks pole ühtegi silti valitud.",
    "unknown text" : "tundmatu tekst",
    "Hello world!" : "Tere maailm!",
    "sunny" : "päikeseline",
    "Hello {name}, the weather is {weather}" : "Tere {name}, ilm on {weather}",
    "Hello {name}" : "Tere, {name}",
    "new" : "uus",
    "_download %n file_::_download %n files_" : ["laadi alla %n fail","laadi alla %n faili"],
    "Updating to {version}" : "Uuendamine versioonile {version}",
    "An error occurred." : "Tekkis tõrge.",
    "Please reload the page." : "Palun laadi see uuesti.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Uuendus ebaõnnestus. Palun teavita probleemidest  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud kogukonda</a>.",
    "The update was successful. There were warnings." : "Uuendamine läks kenasti. hoiatusi polnud.",
    "The update was successful. Redirecting you to ownCloud now." : "Uuendus oli edukas. Kohe suunatakse Sind ownCloudi.",
    "Searching other places" : "Otsi teistest kohtadest",
    "Personal" : "Isiklik",
    "Users" : "Kasutajad",
    "Apps" : "Rakendused",
    "Admin" : "Admin",
    "Help" : "Abiinfo",
    "Access forbidden" : "Ligipääs on keelatud",
    "File not found" : "Faili ei leitud",
    "The specified document has not been found on the server." : "Määratud dokumenti serverist ei leitud.",
    "You can click here to return to %s." : "%s tagasi minemiseks võid sa siia klikkida.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Tere,\n\n%s jagas sulle välja %s.\nVaata siit: %s\n\n",
    "The share will expire on %s." : "Jagamine aegub %s.",
    "Cheers!" : "Terekest!",
    "Internal Server Error" : "Serveri sisemine viga",
    "The server encountered an internal error and was unable to complete your request." : "Serveris tekkis sisemine tõrge ja sinu päringu täitmine ebaõnnestus.",
    "Technical details" : "Tehnilised andmed",
    "Remote Address: %s" : "Kaugaadress: %s",
    "Request ID: %s" : "Päringu ID: %s",
    "Type: %s" : "Tüüp: %s",
    "Code: %s" : "Kood: %s",
    "Message: %s" : "Sõnum: %s",
    "File: %s" : "Fail: %s",
    "Line: %s" : "Rida: %s",
    "Trace" : "Jälita",
    "Imprint" : "Impressum",
    "Privacy Policy" : "Privaatsus",
    "Create an <strong>admin account</strong>" : "Loo <strong>admini konto</strong>",
    "Username" : "Kasutajanimi",
    "Storage & database" : "Andmehoidla ja andmebaas",
    "Data folder" : "Andmete kaust",
    "Configure the database" : "Seadista andmebaasi",
    "Only %s is available." : "Ainult %s on saadaval.",
    "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
    "Database user" : "Andmebaasi kasutaja",
    "Database password" : "Andmebaasi parool",
    "Database name" : "Andmebasi nimi",
    "Database tablespace" : "Andmebaasi tabeliruum",
    "Database host" : "Andmebaasi host",
    "Performance warning" : "Kiiruse hoiatus",
    "SQLite will be used as database." : "Andmebaasina kasutatakse SQLite",
    "Finish setup" : "Lõpeta seadistamine",
    "Finishing …" : "Lõpetamine ...",
    "Need help?" : "Vajad abi?",
    "See the documentation" : "Vaata dokumentatsiooni",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hei,<br><br>annan teada, et %s jagas sinuga <strong>%s</strong>. <a href=\"%s\">Vaata seda!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
    "Menu" : "Menüü",
    "Log out" : "Logi välja",
    "Search" : "Otsi",
    "Server side authentication failed!" : "Serveripoolne autentimine ebaõnnestus!",
    "Please contact your administrator." : "Palun kontakteeru oma süsteemihalduriga.",
    "An internal error occurred." : "Tekkis sisemine tõrge",
    "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
    "Login" : "Logi sisse",
    "Username or email" : "Kasutajanimi või e-posti aadress",
    "Wrong password. Reset it?" : "Vale parool. Kas vajad parooli taastamist?",
    "Wrong password." : "Vale parool.",
    "Stay logged in" : "Püsi sisselogituna",
    "Alternative Logins" : "Alternatiivsed sisselogimisviisid",
    "Use the following link to reset your password: {link}" : "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
    "Password changed successfully" : "Parool on muudetud",
    "New password" : "Uus parool",
    "New Password" : "Uus parool",
    "Confirm Password" : "Kinnita parool",
    "Reset password" : "Nulli parool",
    "This ownCloud instance is currently in single user mode." : "See ownCloud on momendil seadistatud ühe kasutaja jaoks.",
    "This means only administrators can use the instance." : "See tähendab, et seda saavad kasutada ainult administraatorid.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakteeru oma süsteemihalduriga, kui see teade püsib või on tekkinud ootamatult.",
    "Thank you for your patience." : "Täname kannatlikkuse eest.",
    "Two-step verification" : "Kahe-etapiline kinnitamine",
    "Cancel login" : "Tühista sisselogimine",
    "You are accessing the server from an untrusted domain." : "Sa kasutad serverit usalduseta asukohast",
    "App update required" : "Rakenduse uuendus on nõutud",
    "These apps will be updated:" : "Neid rakendusi uuendatakse:",
    "The theme %s has been disabled." : "Teema %s on keelatud.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Enne jätkamist veendu, et andmebaas, seadete ning andmete kataloog on varundatud.",
    "Start update" : "Käivita uuendus",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
    "Detailed logs" : "Üksikasjalikud logid",
    "Update needed" : "On vaja uuendada",
    "This page will refresh itself when the %s instance is available again." : "Se leht laetakse uuesti, kui %s instantsi on uuesti saadaval."
},
"nplurals=2; plural=(n != 1);");
